<template>
  <Dialog v-model="dialogVisible" :title="dialogTitle" width="50%">
    <el-form
      ref="formRef"
      v-loading="formLoading"
      :model="formData"
      :rules="formRules"
      label-width="120px"
    >
      <el-row>
        <el-col :span="12">
          <el-form-item label="服务名" prop="serverName">
            <el-input v-model="formData.serverName" placeholder="请输入服务名"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="IP" prop="host">
            <el-input v-model="formData.host" placeholder="请输入IP"/>
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="用户名" prop="user">
            <el-input v-model="formData.user" placeholder="请输入用户名"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="密码" prop="password">
            <el-input type = "password" v-model="formData.password" placeholder="请输入密码" />
          </el-form-item>
        </el-col>
      </el-row>
      <el-row>
        <el-col :span="12">
          <el-form-item label="设备名" prop="progId">
            <el-input v-model="formData.progId" placeholder="请输入设备名"/>
          </el-form-item>
        </el-col>
        <el-col :span="12">
          <el-form-item label="设备注册表ID" prop="clsId">
            <el-input type="password" v-model="formData.clsId" placeholder="请输入设备注册表ID"/>
          </el-form-item>
        </el-col>
      </el-row>
    </el-form>
    <template #footer>
      <el-button :disabled="formLoading" type="primary" @click="submitForm">确 定</el-button>
      <el-button @click="dialogVisible = false">取 消</el-button>
    </template>
  </Dialog>
</template>
<script lang="ts" setup>
import * as OpcDaApi from '@/api/data/channel/opcda'

defineOptions({name: 'DataOpcDaDeviceForm'})

const {t} = useI18n() // 国际化
const message = useMessage() // 消息弹窗
const dialogVisible = ref(false) // 弹窗的是否展示
const dialogTitle = ref('') // 弹窗的标题
const formLoading = ref(false) // 表单的加载中：1）修改时的数据加载；2）提交的按钮禁用
const formType = ref('') // 表单的类型：create - 新增；update - 修改
const formData = ref({
  id: undefined,
  serverName: undefined,
  host: undefined,
  user: undefined,
  password: undefined,
  progId: undefined,
  clsId: undefined
})
const formRules = reactive({
  serverName: [{required: true, message: '服务名不能为空', trigger: 'blur'}],
  host: [{required: true, message: 'IP不能为空', trigger: 'blur'}],
  user: [{required: true, message: '用户名不能为空', trigger: 'blur'}],
  password: [{required: true, message: '密码不能为空', trigger: 'blur'}]
})
const formRef = ref() // 表单 Ref

/** 打开弹窗 */
const open = async (type: string, id?: number) => {
  dialogVisible.value = true
  dialogTitle.value = t('action.' + type)
  formType.value = type
  resetForm()
  // 修改时，设置数据
  if (id) {
    formLoading.value = true
    try {
      formData.value = await OpcDaApi.getOpcDaDevice(id)
    } finally {
      formLoading.value = false
    }
  }
}
defineExpose({open}) // 提供 open 方法，用于打开弹窗

/** 提交表单 */
const emit = defineEmits(['success']) // 定义 success 事件，用于操作成功后的回调
const submitForm = async () => {
  // 校验表单
  if (!formRef) return
  const valid = await formRef.value.validate()
  if (!valid) return
  // 提交请求
  formLoading.value = true
  try {
    const data = formData.value as unknown as OpcDaApi.OpcDaDeviceVO
    if (formType.value === 'create') {
      await OpcDaApi.createOpcDaDevice(data)
      message.success(t('common.createSuccess'))
    } else {
      await OpcDaApi.updateOpcDaDevice(data)
      message.success(t('common.updateSuccess'))
    }
    dialogVisible.value = false
    // 发送操作成功的事件
    emit('success')
  } finally {
    formLoading.value = false
  }
}

/** 重置表单 */
const resetForm = () => {
  formData.value = {
    id: undefined,
    serverName: undefined,
    host: undefined,
    user: undefined,
    password: undefined,
    progId: undefined,
    clsId: undefined
  }
  formRef.value?.resetFields()
}
</script>
